% Example calls:
% 
%	\documentclass{DOE}
%   \documentclass[draft,pgs,endfloat]{DOE}
%
% Options:
%
%	draft	   insert placeholders for figures; enables a quick compile
%   pgs        add a header with the page number; helpful for counting page length
%   endfloat   push figures to end, one per page, top of page; helpful for editing

\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{DOE}[2016/04/21 Class for preparing ARO grants]

% ===============
% LOAD BASE CLASS
% ===============

\LoadClass[12pt]{article}

% MARGINS
% =======
%
% For an NIH R01 grant, the margins can be as small as 0.50 inches.
% The header and footer should be totally empty -- not even page
% numbers --- since the header and footer will be added when you import
% your pdf into the grants.gov pdf template.
%
% For an ARO grant, the margins need to be 1.00 inch.  Make the default
% top and bottom blank.  The "pgs" option below will add a line at 
% top and bottom and a page number.  With a one inch margin, I find
% I need to tweak footskip from 2ex to 4ex.

\RequirePackage[letterpaper,  
	top=1.00in,
	bottom=1.00in,
	left=1.00in,
	right=1.00in,
	headsep=2ex,
	footskip=4ex]{geometry}

% HEADER
% ======

\RequirePackage{fancyhdr}
\renewcommand{\headrulewidth}{0.4pt} 
\renewcommand{\footrulewidth}{0.4pt}
\pagestyle{fancy}

	\lhead{}
	\chead{}
	\rhead{}
	\lfoot{}
	\cfoot{}  
	\cfoot{}
	\rfoot{}

% FIGURES
% =======
%
% Use the standard graphicx package for figure inclusion.

\RequirePackage{graphicx}

% -----------
% Option: pgs
% -----------
%
% Add a line across the top and bottom of the page and
% add a page number at the bottom of the page.


\DeclareOption{pgs}{
	\renewcommand{\headrulewidth}{0.4pt} 
	\renewcommand{\footrulewidth}{0.4pt}
	\cfoot{\thepage}
}

% ----------------
% Option: endfloat
% ----------------

\newif\if@loadendfloat@  
\DeclareOption{endfloat}{\@loadendfloat@true}

% -------------
% Option: draft
% -------------
%
% Pass this option to the article class AND
% to the graphicx package.  The \setkeys{}
% is a kludge.  See
%
% http://tex.stackexchange.com/questions/9751/draft-mode-after-include-statements

\DeclareOption{draft}{
  \PassOptionsToClass{\CurrentOption}{article}
  \setkeys{Gin}{draft}
}

% ---------------
% Process options
% ---------------

\ProcessOptions\relax

% FIGURE CAPTION
% ==============

% Use the caption package to get small text for figure captions.  
% Add a line below the figure caption.  Finally, 
% allow full-page figures.  See the discussion at 
%
% http://dcwww.camd.dtu.dk/~schiotz/comp/LatexTips/LatexTips.html#figplacement
%
% It is important to import the rotating package before the caption package

\RequirePackage{graphicx}
\RequirePackage[small,
	labelfont=sc,
	labelsep=endash,
	singlelinecheck=false,
	belowskip=-3ex]{caption}

\DeclareCaptionFormat{myformat}{#1#2#3\vspace{-1ex}\hrulefill}
\captionsetup[figure]{format=myformat}

% FIGURE PLACEMENT
% ================
%
% Unless these settings are set JUST SO, using the super option
% with the natbib package puts all the figures at the end of 
% the document -- extremely perplexing!

\renewcommand{\topfraction}{.90}
\renewcommand{\bottomfraction}{.90}
\renewcommand{\textfraction}{.12}
\renewcommand{\floatpagefraction}{.90}
\renewcommand{\dbltopfraction}{.90}
\renewcommand{\dblfloatpagefraction}{.90}
\setcounter{topnumber}{9}
\setcounter{bottomnumber}{9}
\setcounter{totalnumber}{20}
\setcounter{dbltopnumber}{9}

% MATH and UNITS
% ==============

\RequirePackage{amsmath}
\RequirePackage{amssymb}
\let\square=\undefined % SIunits conflict
\RequirePackage{bm}
% \RequirePackage[thickspace]{SIunits}
\RequirePackage{siunitx}
\RequirePackage{cases} 

% TABLES
% ======

\RequirePackage{dcolumn} 

% ENDFLOAT
% ========
% 
% If the endfloat option is invoked, then place figures and 
% tables at the end.  We do not want a list of figures.  We
% want one figure per page, and we want each figure to appear
% at the top of the page.  
%
% This is achieved by modifying \efloatseparator.  Endfloat 
% places \efloatseparator after each float. By default it is
% defined to be \clearpage.  Redefine \efloatseparator so that
% the page is filled to the bottom before the \clearpage.  
% Now each figure appears at the top of its page instead of in
% the center of its page. 

\if@loadendfloat@
  \RequirePackage[nolists,nomarkers]{endfloat}
  \renewcommand{\efloatseparator}{\mbox{} \vfill \clearpage}
\fi

% HYPERLINKS
% ==========
%
% Change the color of hyperlinks to black to conform with
% NIH rules -- no COLOR text.

\RequirePackage[colorlinks=true,
	citecolor=black,
	linkcolor=black,
	urlcolor=black,
	pagebackref=false]{hyperref}

% FONTS
% =====
%
% For an NIH proposal, both Helvetica [San Serif ] and Palatino [serif] 
% are approved fonts.  For online reading, sans-serif will probably
% look nicer.  So ... go with helvetica.
%
% For an ARO proposal , we need Times New Roman @ 12 point

\RequirePackage{times}
\RequirePackage[T1]{fontenc}

% SPACINGS
% ========
%
% Invoking \sloppy helps stop text from spilling into the margins.  The default
% LaTeX hyphenation gives too many word breaks; tweak the hyphenation.  Finally,
% set the paragraph indent and spacing.  Use "ex" for a vertical space in units of
% the font size; use "em" for a horizontal space in units of font size.

\sloppy
\lefthyphenmin=3
\righthyphenmin=4
\setlength\parindent{2em} 
\setlength\parskip{0.5ex} 

% SECTIONING
% ==========
% 
% Redefine the commands for
%
% 	\section{}       Large bold sans-serif font, no label, underline, CR; 
%                     e.g., Research Strategy
%
%   \subsection{}    large bold sans-serif font, label with letter, CR; 
%                     e.g., A. Significance, B. Innovation
%
%   \subsubsection{} normal bold sans-serif font, no label, CR; 
%                     e.g., Overview of the approach, Aim 1
%
%   \paragraph{}     normal bold sans-serif font, long dash, no CR; 
%                     e.g., a Sub-aim
%
% where CR is shorthand for carriage return.  In each case I have trimmed the vertical spacing
% before and after the sectioning commands.  For an ARO proposal, do not reset the page 
% number at the start of each section.

\RequirePackage{titlesec} 

\titleformat{\section}      % the sectioning command to be redefined
	{\Large\bfseries        % the format to be applied to the whole title label and text
	 \sffamily\center}      %
	{}                      % the label; leave it empty if there is no section label
	{0em}                   % horiz separation between label and title body; must be a length
	{}                      % code preceding the title body; could be \setcounter{page}{1}
	% [\titlerule]            % inserts a horizontal line after the heading

\titlespacing*{\section}  % the sectioning command whose spacing is to be adjusting
	{0em}                 % increases the left margin
	{0ex}                 % the vertical space before the title
	{-0.25ex}             % the separation between title and tex

\titlespacing*{\subsection}{0em}{1ex}{1ex}
\titleformat{\subsection}  
	{\large\bfseries\sffamily}  
	{\Alph{subsection}. }                  
	{0em}               
	{}
	[\titlerule]

\titlespacing*{\subsubsection}{0em}{1ex}{-0.25ex}
\titleformat{\subsubsection}{\normalsize\bfseries\sffamily}{}{0em}{}

\newcommand{\subaim}[3]{\paragraph{#1} [Year #2 to #3] ---}
\titlespacing*{\paragraph}{0em}{0ex}{0.50ex}
\titleformat{\paragraph}[runin]
	{\normalsize\bfseries}{}{2em}{}
	    [\hspace{0.0ex}]
% 		[\hspace{0em} \mdseries\rmfamily --- \hspace{0em}]

% CHEMICAL STRUCTURES
% ===================
% 
% For a description of what the chemformula does, see 
% https://ctan.org/tex-archive/macros/latex/contrib/chemformula. 
% The chemformula package will even handle KrogerVink notation! 
% Usage:
% 
% 	mhchem => \ce{H20}
%   chemformula => \ch{H20}
% 

\RequirePackage[version=4]{mhchem}
\RequirePackage{chemformula} 

% LISTS
% =====

\RequirePackage{enumitem}
\setlist[1]{nolistsep,leftmargin=2em}
\setlist[2]{nolistsep,leftmargin=2em}

% BIBLIOGRAPHY
% ============
%
% Need the soul package for underlining, \ul{}.  I am setting 
% the citations to use superscript numbers and not bracketed 
% numbers because this cuts 6 lines from a 12 page NIH proposal
% -- significant.  If you want Physical Review Letters style
% bracketed citations, then use the following import statement
% instead:
% 
% 	\RequirePackage[sort&compress,square,numbers]{natbib}
%

\RequirePackage{soul}
\RequirePackage[super,sort&compress,numbers]{natbib}
\RequirePackage{natmove}

\def\bibsection{
	\clearpage
	\section{Cited References}
	\vspace{2ex}
	}
\setlength{\bibsep}{2ex}
\renewcommand*{\bibfont}{\raggedright}


% NEW COMMANDS
% ============
%
% The command \extendstrategy will create new pages until the 
% page count is twelve.  This command is handy for filling out
% the strategy section while you are writing to see how much 
% space you have to work with. 

\RequirePackage{forloop}
\newcommand{\extendstrategy}[1]{

	\newcounter{pgs}
	\newcounter{init}
	\setcounter{init}{\value{page}}
	\forloop{pgs}{\value{init}}{\value{pgs} < 13}{
		\null\newpage
	}
}

% The command \addhead will create a nice header saying, for example,
%
% 	left top: Army Research Office Proposal
% 	right top: Principal Investigator: Marohn, John A.
%
% in a distinguishing sans-serif font.  To get this header, you 
% would call
%
%	\addhead{Army Research Office Proposal}{Marohn, John A.}

\newcommand{\addhead}[2]{
	\lhead{\textsf{#1}}
	\rhead{\textsf{#2}}
}

% Two commands to help reset the page numbers, one to set the page
% numbers to be lower-case roman numerals and a second one to set
% the page number to be arabic numbers.

\newcommand{\pageresetpreamble}[0]{
	\pagenumbering{roman}
	\setcounter{page}{1}
}

\newcommand{\pageresetmain}[0]{
	\pagenumbering{arabic}
	\setcounter{page}{1}
}

% SUBFILES
% ========
%
% Alternatives to \include{} and input{}, as discussed here:
%
% 	https://en.wikibooks.org/wiki/LaTeX/Modular_Documents
%	http://ftp.math.purdue.edu/mirrors/ctan.org/macros/latex/contrib/subfiles/subfiles.pdf
%	http://mirror.hmc.edu/ctan/macros/latex/contrib/standalone/standalone.pdf

\RequirePackage{subfiles}
\RequirePackage{pdfpages}

% FOR TESTING
% ===========

\RequirePackage{lipsum}

\endinput

	

